@@ -1,4 +1,4 @@
-GOOF----LE-8-2.0      ]l 4  h      ] g  guile	 	g  define-module*	 	 	g  language	g  tree-il	g  
+GOOF----LE-8-2.0$      ]l 4  h      ] g  guile	 	g  define-module*	 	 	g  language	g  tree-il	g  
 primitives		 	
 g  filenameS	f  language/tree-il/primitives.scm	g  importsS	
 g  system	g  base	g  pmatch	
@@ -34,7 +34,7 @@ syntax->datum0/ 1/ 2g  
 datum->syntax32 42 5g  reverse6g  quote7g  
 make-const8g  src9g  make-application:g  self-evaluating?;f  	what what<g  if=f  bad consequent yall>g  
 match-lambda*?, @g  syntax-violationA@ B@ Cf  -source expression failed to match any patternDg  lengthED FD Gg  lastHG I5 J5 Kg  const?Lg  	const-expMg  gensymNf  bOg  make-lexical-refPg  bQg  make-letRP Sg  make-conditionalTg  chained-comparison-expanderUFGHIE V Wg  most-negative-fixnumXg  most-positive-fixnumYg  maybe-simplify-to-eqZf  pre-[f  thunk-\f  post-]g  pre^g  thunk_g  post`]^_ ag  make-dynwindb]_ cg  make-dynrefdg  make-dynseteg  make-promptfg  make-lambda-casegg  tree-il-srchg  argsig  handlerji kg  
-make-abortC 5 h`  b  ]4	
+make-abortC 5 hx  b  ]4	
 &'25 45 >  "  G   R       h0      ]	445  5$  "  	4 5 6       g  name
 		0 g  t		,  g  filenamef  language/tree-il/primitives.scm
 	t
@@ -186,8 +186,8 @@ consequent			| g  in		7	l g  out		7	l  g  filenamef  language
 			O g  w		M g  x			M g  w		+	I  			O
 
 
-   C>  "  G  4iiMFHJ9MKLRQ7? 
-hp  K  -  1  3 " "   $    $  $  45$  45"  $  	"  $  C"  x
+   C>  "  G  4iiMFHJ9MKLRQ?7 
+h  N  -  1  3 " O" "   $    $  $  45$  45"  $  	"  $  C"  x
 $  L45	$  :	(  1	
 454455
  6CC	$  		
@@ -195,14 +195,14 @@ hp  K  -  1  3 " "   $    $  $  45$  4
 	"C
 	"yCCC $    $  $  (  "  45 6"  T45$  E45&  4	5 6	45&  4
 5 6""45$  E45&  4	5 6	45&  4
-5 6"\"X"	""" $  L (   
-6  $  $(  45 6"""     C      g  expr
-		k g  w	 g  x		 g  w		/ g  x		/ g  w		@ g  x		@ g  tail-len		K g  len		` g  ls			|  g  n	
-	|  g  p-ls		|  g  z	   g  w	
-   g  w	   g  w g  x	 g  w	' g  x	' g  w	< g  w%. g  w4g g  x	4g g  w	I_  g  filenamef  language/tree-il/primitives.scm]\	i\	*s\	^	.^	X	X	"X	Z	&Z	 		k
+5 6"\"X"	""" $  9  $  $(  45 6""" $   (   
+6""  F      g  expr
+		~ g  w	" g  x		" g  w		3	 g  x		3	 g  w		D g  x		D g  tail-len		O g  len		d g  ls		   g  n	
+   g  p-ls	   g  z	   g  w	
+   g  w	   g  w g  x	 g  w	+ g  x	+ g  w	@ g  w%X g  x	%X g  w	:P g  wmv  g  filenamef  language/tree-il/primitives.scma\	m\	*w\	^	.^	X	X	"X	Z	&Z	 		~
 
 
-   C>  "  G  4iiNFHJ9N7? 	 h`  a  -  1  3 "   $    $  $  45$  45"  $  	"  $  C"  x
+   C>  "  G  4iiNFHJ9N7? 	      h`  a  -  1  3 "   $    $  $  45$  45"  $  	"  $  C"  x
 $  L45	$  :	(  1	
 454455
  6CC	$  		
@@ -639,11 +639,11 @@ g  filenamef  language/tree-il/primitives.scm
 (h
 ,o
 /s
-3ky
-7#
-8
-9 
-9
+3y
+7;
+8(
+9
+:
 :
 ;
 <
@@ -655,73 +655,74 @@ g  filenamef  language/tree-il/primitives.scm
 B
 C
 D
-E
-G
-H
-I"
-J2
-KB
-LR
-Mb
-Nr
+F
+
+G
+H*
+I:
+JJ
+KZ
+Lj
+Mz
+N
 O
 P
 Q
 R
 S
-V
-Wr
+V5
+W
 X
 Y
-Zh
-[8
-]7
-^>
-_|
+Z
+[P
+]O
+^V
+_
 `
 a
-b
-dU
-e~
+c
+dm
+e
 f
-h
-iu
+h&
+i
 j
-l
-m.
+l
+mF
 n
 o
-q%
-rN
+q=
+rf
 s
 t
-vE
-wn
+v]
+w
 x
-y
-
-
+z
+
+
 	
 
-      J
-      K
-      V	%      `
-      i
-      t	%      ~
+      b
+      c
+      n	%      x
+      
+      	%      
       
-      	      6
-      ?,
-      J-	      -,
-      6=
-      A>	      "=
-      +C
-      6D	      #C
-      ,I
-      7J	      FI
-      OZ
-      Z[	      *Z
-      3o
-      >p	      8o
-      Kv	      ]u
- 	      ]
+      	      N
+      W,
+      b-	      E,
+      N=
+      Y>	      :=
+      CC
+      ND	      ;C
+      DI
+      OJ	      ^I
+      gZ
+      r[	      BZ
+      Ko
+      Vp	      Po
+      cv	      uu
+ 	      u
    C6 
\ No newline at end of file
