@@ -1,4 +1,4 @@
-GOOF----LE-8-2.0M      ]< 4  h      ] g  guile	 	g  define-module*	 	 	g  rnrs	g  
+GOOF----LE-8-2.0 N      ]< 4  h      ] g  guile	 	g  define-module*	 	 	g  rnrs	g  
 arithmetic	g  fixnums		 	
 g  filenameS	f  rnrs/arithmetic/fixnums.scm	g  pureS	
 g  versionS		 	g  set-current-module	 	 	g  resolve-r6rs-interface	 	 	g  only	g  ash	g  cons*	g  define-inlinable	g  inexact->exact	g  logand	g  logbit?	g  logcount	g  logior	g  lognot	g  logxor	 g  most-positive-fixnum	!g  most-negative-fixnum	"g  object-address	# !" 	$g  call-with-deferred-observers	%$ 	&$ 	'g  module-use-interfaces!	(' 	)' 	*g  current-module	+* 	,* 	-g  ice-9	.g  optargs	/-. 	0g  base	10 	2g  control	32 	4g  bitwise	54 	6g  
@@ -7,16 +7,16 @@ exceptions	98 	:g  lists	;: 	<g  module-export!	=< 
 fxcopy-bit	Gg  
 fxbit-set?	Hg  fxfirst-bit-set	Ig  fxlength	Jg  fxbit-count	Kg  fxif	Lg  fxxor	Mg  fxior	Ng  fxand	Og  fxnot	Pg  	fx*/carry	Qg  	fx-/carry	Rg  	fx+/carry	Sg  fxmod0	Tg  fxdiv0	Ug  fxdiv0-and-mod0	Vg  fxmod	Wg  fxdiv	Xg  
 fxdiv-and-mod	Yg  fx-	Zg  fx*	[g  fx+	\g  fxmin	]g  fxmax	^g  fxeven?	_g  fxodd?	`g  fxnegative?	ag  fxpositive?	bg  fxzero?	cg  fx<=?	dg  fx>=?	eg  fx<?	fg  fx>?	gg  fx=?	hg  greatest-fixnum	ig  least-fixnum	jg  fixnum-width	kg  fixnum?	l?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\]^_`abcdefghijk -	mg  module-re-export!	nm 	om 	pg  module-replace!	qp 	rp 	sg  % inline-fixnum?-procedure	tg  make-syntax-transformer	ut 	vt 	wg  inline-fixnum?	xg  macro	yg  $sc-dispatch	zy 	{y 	|g  _	}g  any	~|} 	g  
-syntax-object g  syntax-parameterize g  m-qh9svtEYy3Nm$9dYSIg04r-1510 g  top   g  ribcage g  t-1509     f  l-qh9svtEYy3Nm$9dYSIg04r-1515       g  x   f  l-qh9svtEYy3Nm$9dYSIg04r-1512     g  shift g  	proc-name g  args       f  l-RJ$rxRwEKVaPeeqB2SIw08-121656 f  l-RJ$rxRwEKVaPeeqB2SIw08-121657     g  name g  formals g  body     f  l-RJ$rxRwEKVaPeeqB2SIw08-121647 f  l-RJ$rxRwEKVaPeeqB2SIw08-121648 f  l-RJ$rxRwEKVaPeeqB2SIw08-121649     g  make-procedure-name g  prefix     f  l-RJ$rxRwEKVaPeeqB2SIw08-121635 f  l-RJ$rxRwEKVaPeeqB2SIw08-121633       f  l-RJ$rxRwEKVaPeeqB2SIw08-121632      
+syntax-object g  syntax-parameterize g  m-jB9fp2RNYjF7nnfD0fMOXQ-16579 g  top   g  ribcage g  t-16578     f  l-jB9fp2RNYjF7nnfD0fMOXQ-16584       g  x   f  l-jB9fp2RNYjF7nnfD0fMOXQ-16581     g  shift g  	proc-name g  args       f  l-99zkKrKjayT5wQEm8ES8Zs-121656 f  l-99zkKrKjayT5wQEm8ES8Zs-121657     g  name g  formals g  body     f  l-99zkKrKjayT5wQEm8ES8Zs-121647 f  l-99zkKrKjayT5wQEm8ES8Zs-121648 f  l-99zkKrKjayT5wQEm8ES8Zs-121649     g  make-procedure-name g  prefix     f  l-99zkKrKjayT5wQEm8ES8Zs-121635 f  l-99zkKrKjayT5wQEm8ES8Zs-121633       f  l-99zkKrKjayT5wQEm8ES8Zs-121632      
  g  hygiene       g  private   w  g  identifier-syntax   s        g  lambda   g  obj     g  not   g  =   
     	  "              g  each-any |Ҍ g  syntax-violation     f  Wrong number of arguments f  -source expression failed to match any pattern g  identifier?       s  g  
-assert-fixnum }Ҍ g  or g  dummy g  arg   g  m-qh9svtEYy3Nm$9dYSIg04r-1521     f  l-qh9svtEYy3Nm$9dYSIg04r-1526 f  l-qh9svtEYy3Nm$9dYSIg04r-1527       f  l-qh9svtEYy3Nm$9dYSIg04r-1523         g  and   g  map     w  g  raise   g  make-assertion-violation         g  for-all g  assert-fixnums g  define-fxop*}}} g  defineg  op g  m-qh9svtEYy3Nm$9dYSIg04r-1531  f  l-qh9svtEYy3Nm$9dYSIg04r-1536	f  l-qh9svtEYy3Nm$9dYSIg04r-1537
-f  l-qh9svtEYy3Nm$9dYSIg04r-1538	
+assert-fixnum }Ҍ g  or g  dummy g  arg   g  m-jB9fp2RNYjF7nnfD0fMOXQ-16590     f  l-jB9fp2RNYjF7nnfD0fMOXQ-16595 f  l-jB9fp2RNYjF7nnfD0fMOXQ-16596       f  l-jB9fp2RNYjF7nnfD0fMOXQ-16592         g  and   g  map     w  g  raise   g  make-assertion-violation         g  for-all g  assert-fixnums g  define-fxop*}}} g  defineg  op g  m-jB9fp2RNYjF7nnfD0fMOXQ-16600  f  l-jB9fp2RNYjF7nnfD0fMOXQ-16605	f  l-jB9fp2RNYjF7nnfD0fMOXQ-16606
+f  l-jB9fp2RNYjF7nnfD0fMOXQ-16607	
   
- f  l-qh9svtEYy3Nm$9dYSIg04r-1533 
+ f  l-jB9fp2RNYjF7nnfD0fMOXQ-16602 
    g  case-lambda  g  y       g  apply   !g  >"g  <#g  >=$g  <=%g  zero?&g  	positive?'g  	negative?(g  odd?)g  even?*g  max+g  min,g  )make-implementation-restriction-violation-g  div.g  mod/g  div-and-mod0g  div01g  mod02g  
 div0-and-mod03g  expt4g  
-bitwise-if5g  bitwise-length6g  bitwise-first-bit-set7g  bitwise-copy-bit8g  bitwise-bit-field9g  bitwise-copy-bit-field:g  bitwise-rotate-bit-field;g  bitwise-reverse-bit-fieldC 5       h3    ]4	
+bitwise-if5g  bitwise-length6g  bitwise-first-bit-set7g  bitwise-copy-bit8g  bitwise-bit-field9g  bitwise-copy-bit-field:g  bitwise-rotate-bit-field;g  bitwise-reverse-bit-fieldC 5  h3    ]4	
 
 5 4 >  "  G   4#5 4&), h   M   ] 45 L  6E       g  filenamef  rnrs/arithmetic/fixnums.scm
 	
@@ -63,19 +63,19 @@ bitwise-if5g  bitwise-length6g  bitwise-first-bit-set7g  bitwise-cop
 	k	 		  g  nameg  fixnum? CkR"   h      ]
 	4 5C       g  obj
 		  g  filenamef  rnrs/arithmetic/fixnums.scm
-	n	 		  g  nameg  % inline-fixnum?-procedure CsR4vwx{~    h   .   ]  C      &       g  t-1509
+	n	 		  g  nameg  % inline-fixnum?-procedure CsR4vwx{~    h   /   ]  C      '       g  t-16578
 		
   		
-   Cw      h   _   ]L 6    W       g  a
+   Cw     h   _   ]L 6    W       g  a
 		  g  filenamef  rnrs/arithmetic/fixnums.scm		n	 		   C|     h   O   ] L 6G       g  filenamef  rnrs/arithmetic/fixnums.scm		n	 		
    C   h      ] C          		
    C    hx      ]4 5$  @4 5$   O @4 5"  	 6$  4	 O ?$  
 @""              g  x
 		q g  tmp		q g  tmp		"	q g  tmp		>	q  g  filenamef  rnrs/arithmetic/fixnums.scm
-	n	 		q   C5wR4vx{  h   0   ]  C      (       g  tmp-1530
+	n	 		q   C5wR4vx{  h   1   ]  C      )       g  	tmp-16599
 		
   		
-   C   h   >   ]45C   6       g  dummy
+   C  h   >   ]45C   6       g  dummy
 		 g  arg		  			   C   h(   x   ]	4 5$  @ 6      p       g  x
 		" g  tmp		"  		"  g  
 macro-typeg  syntax-rulesg  patternsg  argg  ...   C5Rs       h       ]	4 5$  C45 6        g  args
