@@ -1,7 +1,7 @@
-GOOF----LE-8-2.04	      ] O 4       hC      ] g  guile	 	g  define-module*	 	 	g  srfi	g  srfi-31	 		g  filenameS	
+GOOF----LE-8-2.0D	      ] O 4       hL      ] g  guile	 	g  define-module*	 	 	g  srfi	g  srfi-31	 		g  filenameS	
 f  srfi/srfi-31.scm	g  exportsS	g  rec	
  	g  set-current-module	 	 	g  cond-expand-provide	g  current-module	 	g  make-syntax-transformer	 	 	g  macro	g  $sc-dispatch	 	 	g  any		g  each-any			 g  
-syntax-object	!g  letrec	"g  top	#" 	$g  ribcage	%g  dummy	&g  name	'g  formals	(g  body	)%&'( 	*g  m-EyyEx6KwlVxUOyAEDecIVd-1529	+*" 	,+### 	-f  l-EyyEx6KwlVxUOyAEDecIVd-1534	.f  l-EyyEx6KwlVxUOyAEDecIVd-1535	/f  l-EyyEx6KwlVxUOyAEDecIVd-1536	0f  l-EyyEx6KwlVxUOyAEDecIVd-1537	1-./0 	2$),1 	3$ 	4g  x	54 	6+ 	7f  l-EyyEx6KwlVxUOyAEDecIVd-1531	87 	9$568 	:#239 	;g  hygiene	<; 	= !:< 	>g  lambda	? >:< 	@ 	Ag  expr	B%&A 	C+## 	Df  l-EyyEx6KwlVxUOyAEDecIVd-1544	Ef  l-EyyEx6KwlVxUOyAEDecIVd-1545	Ff  l-EyyEx6KwlVxUOyAEDecIVd-1546	GDEF 	H$BCG 	I#H39 	J !I< 	Kg  syntax-violation	LK 	MK 	Nf  -source expression failed to match any patternC 5h  r   ]4	
+syntax-object	!g  letrec	"g  top	#" 	$g  ribcage	%g  dummy	&g  name	'g  formals	(g  body	)%&'( 	*g  m-U1jm$YAgHhrlYH0T2xxkpO-16648	+*" 	,+### 	-f  l-U1jm$YAgHhrlYH0T2xxkpO-16653	.f  l-U1jm$YAgHhrlYH0T2xxkpO-16654	/f  l-U1jm$YAgHhrlYH0T2xxkpO-16655	0f  l-U1jm$YAgHhrlYH0T2xxkpO-16656	1-./0 	2$),1 	3$ 	4g  x	54 	6+ 	7f  l-U1jm$YAgHhrlYH0T2xxkpO-16650	87 	9$568 	:#239 	;g  hygiene	<; 	= !:< 	>g  lambda	? >:< 	@ 	Ag  expr	B%&A 	C+## 	Df  l-U1jm$YAgHhrlYH0T2xxkpO-16663	Ef  l-U1jm$YAgHhrlYH0T2xxkpO-16664	Ff  l-U1jm$YAgHhrlYH0T2xxkpO-16665	GDEF 	H$BCG 	I#H39 	J !I< 	Kg  syntax-violation	LK 	MK 	Nf  -source expression failed to match any patternC 5       h  r   ]4	
 
 5 4 >  "  G   4i4i5 >  "  G  4=? h    f   ]   C      ^       g  dummy
 		 g  name		 g  formals			 g  body			  			   C@J  h   Q   ]   C    I       g  dummy
