@@ -1,4 +1,4 @@
-GOOF----LE-8-2.0      ] 4       h      ] g  guile	 	g  define-module*	 	 	g  web	g  client	 		g  filenameS	
+GOOF----LE-8-2.0      ] 4       h       ] g  guile	 	g  define-module*	 	 	g  web	g  client	 		g  filenameS	
 f  web/client.scm	g  importsS	g  rnrs	
 g  bytevectors	
  	 	g  ice-9	g  binary-ports	 	 	g  iconv	 	 	g  rdelim	 	 	g  request	 	 	g  response	 	 	 g  uri	!  	"! 	#g  http	$# 	%$ 	&g  srfi	'g  srfi-1	(&' 	)( 	*g  srfi-9	+&* 	,+ 	-g  gnu	.&*- 	/. 	0"%),/ 	1g  exportsS	2g  current-http-proxy	3g  open-socket-for-uri	4g  http-get	5g  	http-get*	6g  	http-head	7g  	http-post	8g  http-put	9g  http-delete	:g  
@@ -23,11 +23,11 @@ write-request g  write-request-body g  force-output g  request-port g
 read-response g  request-method g  HEAD g  
 close-port g  response-body-port g  decode?S g  read-response-body 	 	 g  
 extra-headersS 	   g  issue-deprecation-warning f  HThe #:extra-headers argument to http-get has been renamed to #:headers.  f  Please update your code.   f  "`http-get*' has been deprecated.   f  BInstead, use `http-get' with the #:streaming? #t keyword argument. g  make-syntax-transformer     g  define-http-verb g  macro g  $sc-dispatch     g  any   g  
-syntax-object g  define* g  top   g  ribcage g  dummy g  	http-verb g  method g  doc   g  m-Ym4oWRt3bBUK7u3ITIABGW-5361     f  l-Ym4oWRt3bBUK7u3ITIABGW-5366 f  l-Ym4oWRt3bBUK7u3ITIABGW-5367 f  l-Ym4oWRt3bBUK7u3ITIABGW-5368 f  l-Ym4oWRt3bBUK7u3ITIABGW-5369       g  x     f  l-Ym4oWRt3bBUK7u3ITIABGW-5363       g  hygiene        g  keyS   g  body       g  port   3      g  version   g  quote          g  keep-alive?     g  headers       g  decode-body?    g  
+syntax-object g  define* g  top   g  ribcage g  dummy g  	http-verb g  method g  doc   g  m-E2pFIuEafMMYInfuy3BPn8-20379     f  l-E2pFIuEafMMYInfuy3BPn8-20384 f  l-E2pFIuEafMMYInfuy3BPn8-20385 f  l-E2pFIuEafMMYInfuy3BPn8-20386 f  l-E2pFIuEafMMYInfuy3BPn8-20387       g  x     f  l-E2pFIuEafMMYInfuy3BPn8-20381       g  hygiene        g  keyS   g  body       g  port   3      g  version   g  quote          g  keep-alive?     g  headers       g  decode-body?    g  
 streaming?   	 	 
    
     
- g  syntax-violation  f  -source expression failed to match any pattern			 g  POSTg  PUTg  DELETEg  TRACEg  OPTIONSC 5 ho  -  ]4	
+ g  syntax-violation  f  -source expression failed to match any pattern			 g  POSTg  PUTg  DELETEg  TRACEg  OPTIONSC 5   ho  -  ]4	
 01<5 4? >  "  G   4@i4AiB5  C$  "    52RDEFGJ      h@      ]4 5$   6"   6 $   &   C""             g  
 uri-or-string
 		:  g  filenamef  web/client.scm
